﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Microsoft.WindowsAPICodePack.Taskbar;

using Microsoft.WindowsAPICodePack.Dialogs;
using Microsoft.WindowsAPICodePack.Shell;
using System.Reflection;
using Microsoft.Win32;

namespace Windows7API
{
    /// <summary>
    /// Interaktionslogik für Window1.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public bool showOverlayIcon { get; set; }
        
        public MainWindow()
        {
            InitializeComponent();


            
            TaskbarManager.Instance.ApplicationId = "MyCompany.MyApplication";
            showOverlayIcon = false;
        }


        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            JumpList list = JumpList.CreateJumpList();            
            list.ClearAllUserTasks();

            string systemFolder = Environment.GetFolderPath(Environment.SpecialFolder.System);
            
            list.AddUserTasks(new JumpListLink(System.IO.Path.Combine(systemFolder, "calc.exe"),
                                                                           "Rechner öffnen")
            {
                IconReference = new IconReference(System.IO.Path.Combine(systemFolder, "calc.exe"), 0)
            });

            list.AddUserTasks(new JumpListLink(System.IO.Path.Combine(systemFolder, "mspaint.exe"),
                                                                            "Paint öffnen")
            {
                IconReference = new IconReference(System.IO.Path.Combine(systemFolder, "mspaint.exe"), 0)
                
            });


            // Persönliche Kategorien
            string myExecutablePath = Assembly.GetEntryAssembly().Location;

            JumpListCustomCategory personalCategory = new JumpListCustomCategory("Persönliche Kategorie");
            list.AddCustomCategories(personalCategory);
                        
            JumpListLink myJumpLinkA = new JumpListLink(myExecutablePath, "Befehl A ausführen");
            myJumpLinkA.IconReference = new IconReference(Assembly.GetEntryAssembly().Location, 0);
            myJumpLinkA.Arguments = "Command-A";
            personalCategory.AddJumpListItems(myJumpLinkA);

            JumpListLink myJumpLinkB = new JumpListLink(myExecutablePath, "Befehl B ausführen");
            myJumpLinkB.IconReference = new IconReference(Assembly.GetEntryAssembly().Location, 0);
            myJumpLinkB.Arguments = "Command-B";
            personalCategory.AddJumpListItems(myJumpLinkB);
            
            list.Refresh();


            // ThumbnailClip

            Point relativePoint 
                = btnOverlay.TransformToAncestor(this).Transform(new Point(0, 0));

            System.Drawing.Point drawingPoint 
                = new System.Drawing.Point((int)relativePoint.X, (int)relativePoint.Y);
            
            System.Drawing.Size drawingSize 
                = new System.Drawing.Size((int)btnOverlay.ActualWidth, (int)btnOverlay.ActualHeight);

            System.Drawing.Rectangle clippingRectangle 
                = new System.Drawing.Rectangle(drawingPoint, drawingSize);
                        
            TaskbarManager.Instance.TabbedThumbnail.SetThumbnailClip(this.Handle, clippingRectangle);
            

            // ThumbnailToolbarButton
            ThumbnailToolbarButton thumbnailButton1 
                = new ThumbnailToolbarButton(Properties.Resources.favourite, "Favorite");
            thumbnailButton1.Click += new EventHandler<ThumbnailButtonClickedEventArgs>(thumbnailButton1_Click);

            ThumbnailToolbarButton thumbnailButton2
                = new ThumbnailToolbarButton(Properties.Resources.restart, "Restart");
            thumbnailButton2.Click += new EventHandler<ThumbnailButtonClickedEventArgs>(thumbnailButton2_Click);

            TaskbarManager.Instance.ThumbnailToolbars.AddButtons(this.Handle, thumbnailButton1, thumbnailButton2);
        }

        
        void thumbnailButton2_Click(object sender, ThumbnailButtonClickedEventArgs e)
        {
            throw new NotImplementedException();
        }
        
        void thumbnailButton1_Click(object sender, ThumbnailButtonClickedEventArgs e)
        {
            throw new NotImplementedException();
        }


        private IntPtr handle;
        public IntPtr Handle
        {
            get
            {
                if (this.handle == IntPtr.Zero)
                {
                    System.Windows.Interop.WindowInteropHelper interopHelper = 
                        new System.Windows.Interop.WindowInteropHelper(this);
                    this.handle = interopHelper.Handle;
                }

                return this.handle;
            }
        }
      




        private void btnOverlay_Click(object sender, RoutedEventArgs e)
        {
            showOverlayIcon = !showOverlayIcon;
            if (showOverlayIcon)
            {
                btnOverlay.Content = "Overlay Icon ausblenden";
                TaskbarManager.Instance.SetOverlayIcon(Properties.Resources.favourite, "Favorite");
            }
            else
            {
                btnOverlay.Content = "Overlay Icon einblenden";
                TaskbarManager.Instance.SetOverlayIcon(null, "");
            }
        }

        private void btnProgressbar_Click(object sender, RoutedEventArgs e)
        {
            AnimateProgressbar(TaskbarProgressBarState.Normal);
        }

        private void btnProgressbarPause_Click(object sender, RoutedEventArgs e)
        {
            AnimateProgressbar(TaskbarProgressBarState.Paused);
        }

        private void btnProgressbarError_Click(object sender, RoutedEventArgs e)
        {
            AnimateProgressbar(TaskbarProgressBarState.Error);
        }

        private void btnProgressbarIndeterminate_Click(object sender, RoutedEventArgs e)
        {
            TaskbarManager.Instance.SetProgressState(TaskbarProgressBarState.Indeterminate);
        }

        private void AnimateProgressbar(TaskbarProgressBarState TaskBarState)
        {
            int minValue = 0;
            int maxValue = 100;

            TaskbarManager.Instance.SetProgressState(TaskBarState);

            for (int value = minValue; value < maxValue; value++)
            {
                TaskbarManager.Instance.SetProgressValue(value, maxValue);
                // Pause von 10 ms. 
                System.Threading.Thread.Sleep(100);
            }

            TaskbarManager.Instance.SetProgressState(TaskbarProgressBarState.NoProgress);
        }

        private void btnChildWindow_Click(object sender, RoutedEventArgs e)
        {
            ChildWindow childWin = new ChildWindow();
            childWin.Show();
        }

        private void btnTaskDialog_Click(object sender, RoutedEventArgs e)
        {
            TaskDialog td = new TaskDialog();
            td.Icon = TaskDialogStandardIcon.Warning;
            td.Caption = "Die Überschrift";
            td.Text = "Wollen Sie die Daten wirklich löschen?";
            td.InstructionText = "Wichtige Mitteilung";
            td.FooterCheckBoxText = "Diese Fenster nicht wieder anzeigen";
            td.FooterIcon = TaskDialogStandardIcon.Information;
            td.StandardButtons = TaskDialogStandardButtons.Yes | TaskDialogStandardButtons.No;
            
            TaskDialogResult res = td.Show();
            if (td.FooterCheckBoxChecked == true)
            {
                
            }
        }

        private void btnTaskDialogTimer_Click(object sender, RoutedEventArgs e)
        {
            TaskDialog td = new TaskDialog();
            td.Icon = TaskDialogStandardIcon.Warning;
            td.Tick += new EventHandler<TaskDialogTickEventArgs>(td_Tick);
            td.InstructionText = "";
            td.Icon = TaskDialogStandardIcon.Shield;
            td.Caption = "TaskDialog mit Timer";
            td.FooterText = "Bitte warten";
            td.Cancelable = true;
            td.Show();
        }

        void td_Tick(object sender, TaskDialogTickEventArgs e)
        {
            TaskDialog td = sender as TaskDialog;
                        
            int seconds =  e.Ticks / 1000;           
            td.InstructionText = string.Format("Vergangene Zeit: {0} Sekunden",seconds);
            
            if (seconds == 5)
            {
                td.Close(TaskDialogResult.Cancel);
            }
        }

        
        int maxValueTicks = 10000;
        
        private void btnTaskDialogProgressTimer_Click(object sender, RoutedEventArgs e)
        {
            TaskDialog tdprogress = new TaskDialog();
            tdprogress.Icon = TaskDialogStandardIcon.Information;
            tdprogress.FooterText = "Bitte warten";
            tdprogress.Caption = "TaskDialog mit Progress Bar";
            tdprogress.Tick += new EventHandler<TaskDialogTickEventArgs>(tdprogress_Tick);
            tdprogress.Cancelable = true;
            tdprogress.StandardButtons = TaskDialogStandardButtons.Cancel;

            TaskDialogProgressBar progressBar = new TaskDialogProgressBar(0, maxValueTicks, 0);
            tdprogress.ProgressBar = progressBar;

            tdprogress.Show();
        }

        void tdprogress_Tick(object sender, TaskDialogTickEventArgs e)
        {
            TaskDialog td = sender as TaskDialog;
            
            if (maxValueTicks >= e.Ticks)
            {
                td.InstructionText = string.Format("Ticks: {0}", e.Ticks);
                td.ProgressBar.Value = e.Ticks;
            }
            else
            {
                td.InstructionText = "Vorgang abgeschlossen.";
                td.FooterText = "";
                td.ProgressBar.Value = maxValueTicks;
            }
        }

        private void btnTaskDialogError_Click(object sender, RoutedEventArgs e)
        {
            TaskDialog tdErrorDialog = new TaskDialog();
            tdErrorDialog.DetailsExpanded = false;
            tdErrorDialog.Cancelable = true;
            tdErrorDialog.Icon = TaskDialogStandardIcon.Error;

            tdErrorDialog.Caption = "Fehler Dialog";
            tdErrorDialog.InstructionText = "Ein unerwarteter Fehler ist aufgetreten.\nBitte senden Sie uns das Fehlerprotokol.";
            tdErrorDialog.Text = "Die Fehlermeldung steht hier.";
            tdErrorDialog.DetailsExpandedLabel = "Fehlerdetails verbergen";
            tdErrorDialog.DetailsCollapsedLabel = "Fehlerdetails anzeigen";
            tdErrorDialog.DetailsExpandedText = "Hier stehen die Fehlerdetails";
            tdErrorDialog.FooterCheckBoxText = "Dieses Fenster nicht wieder anzeigen";
            tdErrorDialog.FooterCheckBoxChecked = false;
            tdErrorDialog.ExpansionMode = TaskDialogExpandedDetailsLocation.ExpandFooter;

            TaskDialogCommandLink sendBtn = new TaskDialogCommandLink("sendButton", "Fehlerprotokol senden\nDas könnte wirklich helfen.");
            sendBtn.Click += new EventHandler(sendBtn_Click);

            TaskDialogCommandLink dontSendBtn = new TaskDialogCommandLink("dontSendButton", "Fehlerprotokol nicht senden\nMeine Fehler gehören mir alleine.");
            dontSendBtn.Click += new EventHandler(dontSendBtn_Click);

            tdErrorDialog.Controls.Add(sendBtn);
            tdErrorDialog.Controls.Add(dontSendBtn);
            tdErrorDialog.Show();
        }

        void dontSendBtn_Click(object sender, EventArgs e)
        {
            TaskDialog td = sender as TaskDialog;
            td.Close(TaskDialogResult.Cancel);
        }

        void sendBtn_Click(object sender, EventArgs e)
        {
            // Etwas sinnvolles tun.
        }

        private void btnCommonOpenFileDialog_Click(object sender, RoutedEventArgs e)
        {
            CommonOpenFileDialog COpenFileDialog = new CommonOpenFileDialog("Bitte Datei wählen");
            COpenFileDialog.Filters.Add(new CommonFileDialogFilter("Bilder", "*.jpg,*.gif,*.png,*.bmp"));
            COpenFileDialog.Multiselect = false;
            COpenFileDialog.EnsureFileExists= true;
            COpenFileDialog.IsFolderPicker = false;
            COpenFileDialog.InitialDirectory = KnownFolders.Desktop.Path;
            
            if (COpenFileDialog.ShowDialog() == CommonFileDialogResult.OK)
            {

            }

            // alt
            //Microsoft.Win32.OpenFileDialog OpenFileDia = new Microsoft.Win32.OpenFileDialog();
            //OpenFileDia.ShowDialog();
        }








    }
}
